@@ -35,3 +35,7 @@ class SubnetTests(testing.TestCase):
                 'usable ips': 22
             },
             json.loads(result.output))
+
+    def test_list(self):
+        result = self.run_command(['subnet',  'list'])
+        self.assert_no_fail(result)
