@@ -672,7 +672,18 @@ class VirtTests(testing.TestCase):
                                    '--memory', '2048MB', '--datacenter',
                                    'TEST00', '--os', 'UBUNTU_LATEST'])
 
-        self.assertEqual(result.exit_code, -1)
+        self.assertEqual(result.exit_code, 0)
+
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_create_vs_flavor_test(self, confirm_mock):
+        confirm_mock.return_value = True
+
+        result = self.run_command(['vs', 'create', '--test', '--hostname', 'TEST',
+                                   '--domain', 'TESTING', '--flavor', 'B1_2X8X25',
+                                   '--datacenter', 'TEST00', '--os', 'UBUNTU_LATEST'])
+
+        self.assert_no_fail(result)
+        self.assertEqual(result.exit_code, 0)
 
     def test_create_vs_bad_memory(self):
         result = self.run_command(['vs', 'create', '--hostname', 'TEST',
@@ -901,6 +912,23 @@ class VirtTests(testing.TestCase):
         self.assertIn({'id': 1122}, order_container['prices'])
         self.assertEqual(order_container['virtualGuests'], [{'id': 100}])
 
+    @mock.patch('SoftLayer.CLI.formatting.confirm')
+    def test_upgrade_with_flavor(self, confirm_mock):
+        confirm_mock.return_value = True
+        result = self.run_command(['vs', 'upgrade', '100', '--flavor=M1_64X512X100'])
+        self.assert_no_fail(result)
+        self.assert_called_with('SoftLayer_Product_Order', 'placeOrder')
+        call = self.calls('SoftLayer_Product_Order', 'placeOrder')[0]
+        order_container = call.args[0]
+        self.assertEqual(799, order_container['presetId'])
+        self.assertIn({'id': 100}, order_container['virtualGuests'])
+        self.assertEqual(order_container['virtualGuests'], [{'id': 100}])
+
+    def test_upgrade_with_cpu_memory_and_flavor(self):
+        result = self.run_command(['vs', 'upgrade', '100', '--cpu=4',
+                                   '--memory=1024', '--flavor=M1_64X512X100'])
+        self.assertEqual("Do not use cpu, private and memory if you are using flavors", str(result.exception))
+
     def test_edit(self):
         result = self.run_command(['vs', 'edit',
                                    '--domain=example.com',
