@@ -540,6 +540,47 @@ class DedicatedHostTests(testing.TestCase):
         self.assertRaises(exceptions.SoftLayerError,
                           self.dedicated_host._get_default_router, routers, 'notFound')
 
+    def test_cancel_host(self):
+        result = self.dedicated_host.cancel_host(789)
+
+        self.assertEqual(result, True)
+        self.assert_called_with('SoftLayer_Virtual_DedicatedHost', 'deleteObject', identifier=789)
+
+    def test_cancel_guests(self):
+        vs1 = {'id': 987, 'fullyQualifiedDomainName': 'foobar.example.com'}
+        vs2 = {'id': 654, 'fullyQualifiedDomainName': 'wombat.example.com'}
+        self.dedicated_host.host = mock.Mock()
+        self.dedicated_host.host.getGuests.return_value = [vs1, vs2]
+
+        # Expected result
+        vs_status1 = {'id': 987, 'fqdn': 'foobar.example.com', 'status': 'Cancelled'}
+        vs_status2 = {'id': 654, 'fqdn': 'wombat.example.com', 'status': 'Cancelled'}
+        delete_status = [vs_status1, vs_status2]
+
+        result = self.dedicated_host.cancel_guests(789)
+
+        self.assertEqual(result, delete_status)
+
+    def test_cancel_guests_empty_list(self):
+        self.dedicated_host.host = mock.Mock()
+        self.dedicated_host.host.getGuests.return_value = []
+
+        result = self.dedicated_host.cancel_guests(789)
+
+        self.assertEqual(result, [])
+
+    def test_delete_guest(self):
+        result = self.dedicated_host._delete_guest(123)
+        self.assertEqual(result, 'Cancelled')
+
+        # delete_guest should return the exception message in case it fails
+        error_raised = SoftLayer.SoftLayerAPIError('SL Exception', 'SL message')
+        self.dedicated_host.guest = mock.Mock()
+        self.dedicated_host.guest.deleteObject.side_effect = error_raised
+
+        result = self.dedicated_host._delete_guest(369)
+        self.assertEqual(result, 'Exception: SL message')
+
     def _get_routers_sample(self):
         routers = [
             {
@@ -647,3 +688,34 @@ class DedicatedHostTests(testing.TestCase):
         }
 
         return package
+
+    def test_list_guests(self):
+        results = self.dedicated_host.list_guests(12345)
+
+        for result in results:
+            self.assertIn(result['id'], [200, 202])
+        self.assert_called_with('SoftLayer_Virtual_DedicatedHost', 'getGuests', identifier=12345)
+
+    def test_list_guests_with_filters(self):
+        self.dedicated_host.list_guests(12345, tags=['tag1', 'tag2'], cpus=2, memory=1024,
+                                        hostname='hostname', domain='example.com', nic_speed=100,
+                                        public_ip='1.2.3.4', private_ip='4.3.2.1')
+
+        _filter = {
+            'guests': {
+                'domain': {'operation': '_= example.com'},
+                'tagReferences': {
+                    'tag': {'name': {
+                        'operation': 'in',
+                        'options': [{
+                            'name': 'data', 'value': ['tag1', 'tag2']}]}}},
+                'maxCpu': {'operation': 2},
+                'maxMemory': {'operation': 1024},
+                'hostname': {'operation': '_= hostname'},
+                'networkComponents': {'maxSpeed': {'operation': 100}},
+                'primaryIpAddress': {'operation': '_= 1.2.3.4'},
+                'primaryBackendIpAddress': {'operation': '_= 4.3.2.1'}
+            }
+        }
+        self.assert_called_with('SoftLayer_Virtual_DedicatedHost', 'getGuests',
+                                identifier=12345, filter=_filter)
